<template>
	<HMContainer type="card">
		<template #header>
			<el-form ref="queryFormRef" :inline="true" :model="queryParams">
				<el-form-item label="名称" prop="title">
					<el-input v-model="queryParams.title" style="width: 226.4px" placeholder="名称" clearable />
				</el-form-item>
				<el-form-item label="主题域" prop="themeDomainID">
					<el-tree-select
						filterable
						style="width: 256.4px"
						v-model="queryParams.themeDomainID"
						:data="listTreeData"
						:props="{
							id: 'id',
							label: 'name',
							children: 'Children',
						}"
						multiple
						node-key="id"
						:clearable="true"
						:accordion="true"
						:expandNode="false"
						default-expand-all
						:check-strictly="true"
						placeholder="请选择主题域"
						@change="selectThemeChange"
					>
					</el-tree-select>
				</el-form-item>
				<el-form-item label="敏感度" prop="sensitivity">
					<el-select v-model="queryParams.sensitivity" style="width: 226.4px" clearable>
						<el-option
							v-for="item in Object.keys(eMetrics_Ops)"
							:key="item"
							:value="parseInt(item)"
							:label="eMetrics_Ops[item]"
						></el-option>
					</el-select>
				</el-form-item>
				<el-form-item>
					<el-button type="primary" icon="ele-Search" @click="handleQueryTable"> 查询 </el-button>
					<el-button icon="ele-Refresh" @click="resetQuery">重置 </el-button>
					<!-- <el-button icon="ele-Plus" @click="openOptDlg()"> 添加 </el-button> -->
				</el-form-item>
			</el-form>
		</template>
		<template #main>
			<div class="h-full" ref="chatDragContainerRef">
				<el-table
					v-loading="tableLoading"
					ref="draggableTableRef"
					class="h100"
					border
					:row-class-name="isDragStatus ? 'cursor-move' : 'cursor-pointer'"
					:data="displayTableData"
					highlight-current-row
					:cell-style="tableCellCenterExceptColumn()"
					:headerCellStyle="{ backgroundColor: 'var(--el-table-header-bg-color)', textAlign: 'center' }"
				>
					<el-table-column prop="title" label="指标名称" width="120" fixed="left" show-overflow-tooltip>
						<template #default="scope">
							<div class="text-[#1677ff]" @click="handleClickTitleRow(scope.row)">{{ scope.row.title }}</div>
						</template>
					</el-table-column>
					<el-table-column prop="full_name" label="指标全称" show-overflow-tooltip> </el-table-column>
					<el-table-column label="重要性" prop="metrics_important" show-overflow-tooltip width="80">
						<template #default="scope">
							{{ eMetrics_Ops[scope.row.metrics_important] }}
						</template>
					</el-table-column>
					<el-table-column prop="metrics_define" label="指标定义" show-overflow-tooltip> </el-table-column>
					<el-table-column prop="calcu_method" label="指标计算公式" width="120" show-overflow-tooltip> </el-table-column>
					<el-table-column prop="metrics_type" label="类别" show-overflow-tooltip width="120"> </el-table-column>
					<el-table-column label="操作" width="80" fixed="right" show-overflow-tooltip>
						<template #default="scope">
							<div class="space-x-3 items-center flex">
								<el-tooltip
									effect="dark"
									:content="scope.row.published === SupervisorPublished.Y ? '取消发布' : '发布'"
									placement="top"
								>
									<i
										class="ywifont !text-[20px] cursor-pointer"
										:class="[
											scope.row.published === SupervisorPublished.Y ? 'ywicon-quxiaofabu text-red-400' : 'ywicon-fabu text-blue-400',
										]"
										@click="
											publishStatusChange(
												scope.row.published === SupervisorPublished.Y ? SupervisorPublished.N : SupervisorPublished.Y,
												scope.row.id,
												scope.$index
											)
										"
									></i>
								</el-tooltip>
							</div>
						</template>
					</el-table-column>
				</el-table>
			</div>
		</template>

		<!-- <OptDlg v-model="optDlgIsShow" :item="optDlgMapRow" @insert="insertOpt" @update="updateOpt" :groupId="currentListID"></OptDlg> -->
		<!-- <MetricPrompt v-model="infoDlgIsShow" :metricItem="infoDlgMapRow"></MetricPrompt>
		<MetricName v-model="metricNameIsShow" :metricItem="metricNameMapRow"></MetricName> -->
	</HMContainer>
</template>

<script setup lang="ts">
import { computed, onMounted, ref } from 'vue';
import { useRouter } from 'vue-router';
import { SupervisorPublished } from '../../lowCode/sqlAmis/types';
import * as metricApi from '/@/api/metrics';
import HMContainer from '/@/components/layout/HMContainer.vue';
import { usePageDisplay } from '/@/hooks/usePageDisplay';
import { useQueryTable } from '/@/hooks/useQueryTable';
import { convertListToTree, tableCellCenterExceptColumn } from '/@/utils/util';
import { eMetrics_Ops } from '/@/views/types/metrics';
const router = useRouter();
//#region ====================== 表格数据，table init ======================
const tableLoading = ref(false);
const tableData = ref([]);
const isDragStatus = ref(false);
const getTableData = async () => {
	const res = await metricApi.getMetricNameListByPost();
	const data = res?.values ?? [];
	const filterData = Array.from(new Set(data));
	tableData.value = filterData;
};
//#endregion

//#region ====================== 表格查询、排序，search form init ======================
const themeDomainData = ref([
	{
		createdBy: 'admin',
		updatedBy: 'admin',
		createdAt: '2024-10-08T02:03:38.901+00:00',
		updatedAt: '2024-10-08T02:03:38.901+00:00',
		id: 1,
		name: '超音数',
		bizName: 'supersonic',
		description: null,
		status: 1,
		typeEnum: null,
		sensitiveLevel: 0,
		parentId: 0,
		fullPath: 'supersonic/',
		viewers: ['admin', 'tom'],
		viewOrgs: [],
		admins: ['admin', 'jack'],
		adminOrgs: [],
		isOpen: 0,
		hasEditPermission: true,
		hasModel: false,
	},
	{
		createdBy: 'admin',
		updatedBy: 'admin',
		createdAt: '2024-10-08T02:03:38.913+00:00',
		updatedAt: '2024-10-08T02:03:38.913+00:00',
		id: 2,
		name: '埋点模型集',
		bizName: 'visit_info',
		description: null,
		status: 1,
		typeEnum: null,
		sensitiveLevel: 0,
		parentId: 1,
		fullPath: 'supersonic/visit_info/',
		viewers: [],
		viewOrgs: [],
		admins: [],
		adminOrgs: [],
		isOpen: 0,
		hasEditPermission: true,
		hasModel: true,
	},
	{
		createdBy: 'admin',
		updatedBy: 'admin',
		createdAt: '2024-10-08T02:03:52.593+00:00',
		updatedAt: '2024-10-08T02:03:52.593+00:00',
		id: 3,
		name: '艺人库',
		bizName: 'singer',
		description: null,
		status: 1,
		typeEnum: null,
		sensitiveLevel: 0,
		parentId: 0,
		fullPath: 'singer/',
		viewers: ['admin', 'tom', 'jack'],
		viewOrgs: ['1'],
		admins: ['admin', 'alice'],
		adminOrgs: [],
		isOpen: 0,
		hasEditPermission: true,
		hasModel: false,
	},
	{
		createdBy: 'admin',
		updatedBy: 'admin',
		createdAt: '2024-10-08T02:03:52.594+00:00',
		updatedAt: '2024-10-08T02:03:52.594+00:00',
		id: 4,
		name: '标签模型集',
		bizName: 'singer_info',
		description: null,
		status: 1,
		typeEnum: null,
		sensitiveLevel: 0,
		parentId: 3,
		fullPath: 'singer/singer_info/',
		viewers: [],
		viewOrgs: [],
		admins: [],
		adminOrgs: [],
		isOpen: 0,
		hasEditPermission: true,
		hasModel: true,
	},
]); // 主题域数据
const listTreeData = computed(() => {
	return convertListToTree(themeDomainData.value, {
		ID: 'id',
		Children: 'Children',
		ParentID: 'parentId',
	});
});
const selectThemeChange = async (value: string) => {
	return;
	const res = await metricApi.getThemeDomainByPost({
		equipmentLocationID: value,
	});
	themeDomainData.value = res.values;
};
const queryParams = ref({
	title: '',
	// themeDomainID: null,
	sensitivity: '',
});
const { resetQuery, handleQueryTable, displayTableData } = useQueryTable(tableData, queryParams, () => {
	displayTableData.value = tableData.value;
});
const handleClickTitleRow = (row: any) => {
	router.push({
		name: 'MetricDetail',
	});
};
//#endregion

//#region ====================== 查询快捷键 ======================
const queryFormRef = ref(null);
const pressEnterSearch = (ev: KeyboardEvent) => {
	if (ev.key === 'Enter') {
		handleQueryTable();
	}
};
usePageDisplay(
	() => {
		queryFormRef.value?.$el?.addEventListener('keypress', pressEnterSearch);
	},
	() => {
		queryFormRef.value?.$el?.removeEventListener('keypress', pressEnterSearch);
	}
);
//#endregion

//#region ====================== 添加修改操作 ======================
const optDlgIsShow = ref(false);
const optDlgMapRow = ref(null);
const openOptDlg = (row?: any) => {
	optDlgMapRow.value = row;
	optDlgIsShow.value = true;
};

const updateOpt = (formValue) => {
	const foundIndex = tableData.value.findIndex((item) => item.id === formValue.id);
	if (foundIndex > -1) {
		tableData.value[foundIndex] = {
			...tableData.value[foundIndex],
			...formValue,
		};
	}
};

const insertOpt = (newData) => {
	tableData.value.unshift({ ...newData, published: SupervisorPublished.N });
};
//#endregion

const updatePublishedById = (id: string, published: SupervisorPublished) => {
	const row = tableData.value.find((item) => item.id === id);
	if (row) {
		row.published = published;
	}
};
//#region ====================== 改变发布状态 ======================
const publishStatusChange = async (published: SupervisorPublished, id, index) => {
	return;
	const res = await updatePublishStatus(
		{
			id: id,
			publish: published,
		},
		{
			loading: false,
		}
	);
	const origin = published === SupervisorPublished.Y ? SupervisorPublished.N : SupervisorPublished.Y;
	const final = res.publish ?? origin;
	if (final === origin) {
		ElMessage.warning('操作失败' + (res.fail_msg ? `：${res.fail_msg}` : ''));
		return;
	}

	tableData.value[index].published = final;

	published === SupervisorPublished.Y ? ElMessage.success('发布成功') : ElMessage.info('已取消发布');
};
//#endregion

//#region ====================== 更新发布状态 ======================
// useUpdateData({
// 	event: 'supervisor.publish',
// 	updateFun({ id, published }) {
// 		updatePublishedById(id, published);
// 	},
// });
//#endregion
onMounted(() => {
	getTableData();
});
</script>
<style scoped lang="scss"></style>
import { ElMessage } from 'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from
'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin'; import { ElMessage } from 'element-plus'; import {
updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import { updatePublishStatus } from
'/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import
{ ElMessage } from 'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from
'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import {
updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import { updatePublishStatus } from
'/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import
{ ElMessage } from 'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from
'element-plus'; import { updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import {
updatePublishStatus } from '/@/api/supervisorAdmin';import { ElMessage } from 'element-plus'; import { updatePublishStatus } from
'/@/api/supervisorAdmin';
